# - AthenaServer -
[![pypi](https://img.shields.io/pypi/v/AthenaServer)](https://pypi.org/project/AthenaServer/) [![GitHub license](https://img.shields.io/github/license/DirectiveAthena/AthenaServer)](https://github.com/DirectiveAthena/VerSC-AthenaColor/blob/master/LICENSE) [![Discord](https://img.shields.io/discord/814599159926620160?color=maroon)](https://discord.gg/6JcDbhXkCH) [![Downloads](https://pepy.tech/badge/athenaserver)](https://pepy.tech/project/athenaserver)

--- 
## Package Details
#### Details and features 
- A general server system for Directive Athena Applications
- Isn't dependent on 3rd party packages, except for those that have been created by [@AndreasSas](https://github.com/AndreasSas)
  - These can be designated by the leading "*Athena*..."
  - These packages aren't seen as a 3rd party dependency as they are all made by the "same party"

#### Python Version
- Supported Python versions: **3.10**
  - Other older versions of Python are not currently supported. 
  - These older versions will probably not be supported by [@AndreasSas](https://github.com/AndreasSas) himself, but if you want to contribute to the project and make this package compatible with older versions of Python, Pull requests are always welcome.

---
## Documentation
Full documentation can be found at:
**[directiveathena.com/docu](https://publish.obsidian.md/directiveathena/)** (redirect to Obsidian.md publish site)
(Reminder, the documentation is still under heavy development)

---
## Install
To install the package in your Python environment

```
pip install AthenaServer --upgrade
```

---

## Links 
Project files can be found at:    
- [GitHub Repo](https://github.com/DirectiveAthena/AthenaServer)     
- [Pypi link](https://pypi.org/project/AthenaServer/)    

---

## Disclaimer
With  *No Dependency*, the standard library is not counted as a dependency

---
Made By Andreas Sas,` 2022`
